#!/usr/bin/env python
# cardinal_pythonlib/django/tools/generate_new_django_secret_key.py

"""
===============================================================================

    Original code copyright (C) 2009-2018 Rudolf Cardinal (rudolf@pobox.com).

    This file is part of cardinal_pythonlib.

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

===============================================================================

**Generates a new random secret key suitable for use with Django.**

See ``django.core.management.commands.startproject.Command.handle``.
"""

from django.utils.crypto import get_random_string


def main() -> None:
    """
    Generates a new Django secret key and prints it to stdout.
    """
    chars = 'abcdefghijklmnopqrstuvwxyz0123456789!@#$%^&*(-_=+)'  # valid chars
    key = get_random_string(50, chars)
    print(key)


if __name__ == '__main__':
    main()
